nan

package module
v1.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 30, 2025 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type NullBool

type NullBool struct {
	Bool  bool
	Valid bool // Valid is true if Bool is not NULL
}

NullBool - nullable bool

func Bool

func Bool(v bool) NullBool

Bool - converts bool to NullBool

func BoolAddr

func BoolAddr(v *bool) NullBool

BoolAddr - converts bool address to NullBool

func BoolToNullBool deprecated

func BoolToNullBool(v bool) NullBool

BoolToNullBool - converts bool to NullBool

Deprecated: use shorter variant

func (NullBool) Addr

func (n NullBool) Addr() *bool

func (*NullBool) DecodeMsg added in v1.2.0

func (z *NullBool) DecodeMsg(dc *msgp.Reader) (err error)

DecodeMsg implements msgp.Decodable

func (NullBool) EncodeMsg added in v1.2.0

func (z NullBool) EncodeMsg(en *msgp.Writer) (err error)

EncodeMsg implements msgp.Encodable

func (NullBool) IsDefined

func (n NullBool) IsDefined() bool

func (NullBool) IsValid

func (n NullBool) IsValid() bool

func (NullBool) MarshalMsg added in v1.2.0

func (z NullBool) MarshalMsg(b []byte) (o []byte, err error)

MarshalMsg implements msgp.Marshaler

func (NullBool) Msgsize added in v1.2.0

func (z NullBool) Msgsize() (s int)

Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message

func (*NullBool) Scan

func (n *NullBool) Scan(value interface{}) error

Scan - scan value from sql driver

func (*NullBool) UnmarshalMsg added in v1.2.0

func (z *NullBool) UnmarshalMsg(bts []byte) (o []byte, err error)

UnmarshalMsg implements msgp.Unmarshaler

func (NullBool) Value

func (n NullBool) Value() (driver.Value, error)

Value implements the driver Valuer interface.

type NullFloat32

type NullFloat32 struct {
	Float32 float32
	Valid   bool // Valid is true if Float32 is not NULL
}

NullFloat32 - nullable float32

func Float32

func Float32(v float32) NullFloat32

Float32 - converts float32 to NullFloat32

func Float32Addr

func Float32Addr(v *float32) NullFloat32

Float32Addr - converts float32 address to NullFloat32

func Float32ToNullFloat32 deprecated

func Float32ToNullFloat32(v float32) NullFloat32

Float32ToNullFloat32 - converts float32 to NullFloat32

Deprecated: use shorter variant

func (NullFloat32) Addr

func (n NullFloat32) Addr() *float32

func (*NullFloat32) DecodeMsg added in v1.2.0

func (z *NullFloat32) DecodeMsg(dc *msgp.Reader) (err error)

DecodeMsg implements msgp.Decodable

func (NullFloat32) EncodeMsg added in v1.2.0

func (z NullFloat32) EncodeMsg(en *msgp.Writer) (err error)

EncodeMsg implements msgp.Encodable

func (NullFloat32) IsDefined

func (n NullFloat32) IsDefined() bool

func (NullFloat32) IsValid

func (n NullFloat32) IsValid() bool

func (NullFloat32) MarshalMsg added in v1.2.0

func (z NullFloat32) MarshalMsg(b []byte) (o []byte, err error)

MarshalMsg implements msgp.Marshaler

func (NullFloat32) Msgsize added in v1.2.0

func (z NullFloat32) Msgsize() (s int)

Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message

func (*NullFloat32) Scan

func (n *NullFloat32) Scan(value interface{}) error

Scan - scan value from sql driver

func (*NullFloat32) UnmarshalMsg added in v1.2.0

func (z *NullFloat32) UnmarshalMsg(bts []byte) (o []byte, err error)

UnmarshalMsg implements msgp.Unmarshaler

func (NullFloat32) Value

func (n NullFloat32) Value() (driver.Value, error)

Value implements the driver Valuer interface.

type NullFloat64

type NullFloat64 struct {
	Float64 float64
	Valid   bool // Valid is true if Float64 is not NULL
}

NullFloat64 - nullable float64

func Float64

func Float64(v float64) NullFloat64

Float64 - converts float64 to NullFloat64

func Float64Addr

func Float64Addr(v *float64) NullFloat64

Float64Addr - converts float64 address to NullFloat64

func Float64ToNullFloat64 deprecated

func Float64ToNullFloat64(v float64) NullFloat64

Float64ToNullFloat64 - converts float64 to NullFloat64

Deprecated: use shorter variant

func (NullFloat64) Addr

func (n NullFloat64) Addr() *float64

func (*NullFloat64) DecodeMsg added in v1.2.0

func (z *NullFloat64) DecodeMsg(dc *msgp.Reader) (err error)

DecodeMsg implements msgp.Decodable

func (NullFloat64) EncodeMsg added in v1.2.0

func (z NullFloat64) EncodeMsg(en *msgp.Writer) (err error)

EncodeMsg implements msgp.Encodable

func (NullFloat64) IsDefined

func (n NullFloat64) IsDefined() bool

func (NullFloat64) IsValid

func (n NullFloat64) IsValid() bool

func (NullFloat64) MarshalMsg added in v1.2.0

func (z NullFloat64) MarshalMsg(b []byte) (o []byte, err error)

MarshalMsg implements msgp.Marshaler

func (NullFloat64) Msgsize added in v1.2.0

func (z NullFloat64) Msgsize() (s int)

Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message

func (*NullFloat64) Scan

func (n *NullFloat64) Scan(value interface{}) error

Scan - scan value from sql driver

func (*NullFloat64) UnmarshalMsg added in v1.2.0

func (z *NullFloat64) UnmarshalMsg(bts []byte) (o []byte, err error)

UnmarshalMsg implements msgp.Unmarshaler

func (NullFloat64) Value

func (n NullFloat64) Value() (driver.Value, error)

Value implements the driver Valuer interface.

type NullInt

type NullInt struct {
	Int   int
	Valid bool // Valid is true if Int is not NULL
}

NullInt - nullable int

func Int

func Int(v int) NullInt

Int - converts int to NullInt

func IntAddr

func IntAddr(v *int) NullInt

IntAddr - converts int address to NullInt

func IntToNullInt deprecated

func IntToNullInt(v int) NullInt

IntToNullInt - converts int to NullInt

Deprecated: use shorter variant

func (NullInt) Addr

func (n NullInt) Addr() *int

func (*NullInt) DecodeMsg added in v1.2.0

func (z *NullInt) DecodeMsg(dc *msgp.Reader) (err error)

DecodeMsg implements msgp.Decodable

func (NullInt) EncodeMsg added in v1.2.0

func (z NullInt) EncodeMsg(en *msgp.Writer) (err error)

EncodeMsg implements msgp.Encodable

func (NullInt) IsDefined

func (n NullInt) IsDefined() bool

func (NullInt) IsValid

func (n NullInt) IsValid() bool

func (NullInt) MarshalMsg added in v1.2.0

func (z NullInt) MarshalMsg(b []byte) (o []byte, err error)

MarshalMsg implements msgp.Marshaler

func (NullInt) Msgsize added in v1.2.0

func (z NullInt) Msgsize() (s int)

Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message

func (*NullInt) Scan

func (n *NullInt) Scan(value interface{}) error

Scan - scan value from sql driver

func (*NullInt) UnmarshalMsg added in v1.2.0

func (z *NullInt) UnmarshalMsg(bts []byte) (o []byte, err error)

UnmarshalMsg implements msgp.Unmarshaler

func (NullInt) Value

func (n NullInt) Value() (driver.Value, error)

Value implements the driver Valuer interface.

type NullInt8

type NullInt8 struct {
	Int8  int8
	Valid bool // Valid is true if Int8 is not NULL
}

NullInt8 - nullable int8

func Int8

func Int8(v int8) NullInt8

Int8 - converts int8 to NullInt8

func Int8Addr

func Int8Addr(v *int8) NullInt8

Int8Addr - converts int8 address to NullInt8

func Int8ToNullInt8 deprecated

func Int8ToNullInt8(v int8) NullInt8

Int8ToNullInt8 - converts int8 to NullInt8

Deprecated: use shorter variant

func (NullInt8) Addr

func (n NullInt8) Addr() *int8

func (*NullInt8) DecodeMsg added in v1.2.0

func (z *NullInt8) DecodeMsg(dc *msgp.Reader) (err error)

DecodeMsg implements msgp.Decodable

func (NullInt8) EncodeMsg added in v1.2.0

func (z NullInt8) EncodeMsg(en *msgp.Writer) (err error)

EncodeMsg implements msgp.Encodable

func (NullInt8) IsDefined

func (n NullInt8) IsDefined() bool

func (NullInt8) IsValid

func (n NullInt8) IsValid() bool

func (NullInt8) MarshalMsg added in v1.2.0

func (z NullInt8) MarshalMsg(b []byte) (o []byte, err error)

MarshalMsg implements msgp.Marshaler

func (NullInt8) Msgsize added in v1.2.0

func (z NullInt8) Msgsize() (s int)

Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message

func (*NullInt8) Scan

func (n *NullInt8) Scan(value interface{}) error

Scan - scan value from sql driver

func (*NullInt8) UnmarshalMsg added in v1.2.0

func (z *NullInt8) UnmarshalMsg(bts []byte) (o []byte, err error)

UnmarshalMsg implements msgp.Unmarshaler

func (NullInt8) Value

func (n NullInt8) Value() (driver.Value, error)

Value implements the driver Valuer interface.

type NullInt16

type NullInt16 struct {
	Int16 int16
	Valid bool // Valid is true if Int16 is not NULL
}

NullInt16 - nullable int16

func Int16

func Int16(v int16) NullInt16

Int16 - converts int16 to NullInt16

func Int16Addr

func Int16Addr(v *int16) NullInt16

Int16Addr - converts int16 address to NullInt16

func Int16ToNullInt16 deprecated

func Int16ToNullInt16(v int16) NullInt16

Int16ToNullInt16 - converts int16 to NullInt16

Deprecated: use shorter variant

func (NullInt16) Addr

func (n NullInt16) Addr() *int16

func (*NullInt16) DecodeMsg added in v1.2.0

func (z *NullInt16) DecodeMsg(dc *msgp.Reader) (err error)

DecodeMsg implements msgp.Decodable

func (NullInt16) EncodeMsg added in v1.2.0

func (z NullInt16) EncodeMsg(en *msgp.Writer) (err error)

EncodeMsg implements msgp.Encodable

func (NullInt16) IsDefined

func (n NullInt16) IsDefined() bool

func (NullInt16) IsValid

func (n NullInt16) IsValid() bool

func (NullInt16) MarshalMsg added in v1.2.0

func (z NullInt16) MarshalMsg(b []byte) (o []byte, err error)

MarshalMsg implements msgp.Marshaler

func (NullInt16) Msgsize added in v1.2.0

func (z NullInt16) Msgsize() (s int)

Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message

func (*NullInt16) Scan

func (n *NullInt16) Scan(value interface{}) error

Scan - scan value from sql driver

func (*NullInt16) UnmarshalMsg added in v1.2.0

func (z *NullInt16) UnmarshalMsg(bts []byte) (o []byte, err error)

UnmarshalMsg implements msgp.Unmarshaler

func (NullInt16) Value

func (n NullInt16) Value() (driver.Value, error)

Value implements the driver Valuer interface.

type NullInt32

type NullInt32 struct {
	Int32 int32
	Valid bool // Valid is true if Int32 is not NULL
}

NullInt32 - nullable int32

func Int32

func Int32(v int32) NullInt32

Int32 - converts int32 to NullInt32

func Int32Addr

func Int32Addr(v *int32) NullInt32

Int32Addr - converts int32 address to NullInt32

func Int32ToNullInt32 deprecated

func Int32ToNullInt32(v int32) NullInt32

Int32ToNullInt32 - converts int32 to NullInt32

Deprecated: use shorter variant

func (NullInt32) Addr

func (n NullInt32) Addr() *int32

func (*NullInt32) DecodeMsg added in v1.2.0

func (z *NullInt32) DecodeMsg(dc *msgp.Reader) (err error)

DecodeMsg implements msgp.Decodable

func (NullInt32) EncodeMsg added in v1.2.0

func (z NullInt32) EncodeMsg(en *msgp.Writer) (err error)

EncodeMsg implements msgp.Encodable

func (NullInt32) IsDefined

func (n NullInt32) IsDefined() bool

func (NullInt32) IsValid

func (n NullInt32) IsValid() bool

func (NullInt32) MarshalMsg added in v1.2.0

func (z NullInt32) MarshalMsg(b []byte) (o []byte, err error)

MarshalMsg implements msgp.Marshaler

func (NullInt32) Msgsize added in v1.2.0

func (z NullInt32) Msgsize() (s int)

Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message

func (*NullInt32) Scan

func (n *NullInt32) Scan(value interface{}) error

Scan - scan value from sql driver

func (*NullInt32) UnmarshalMsg added in v1.2.0

func (z *NullInt32) UnmarshalMsg(bts []byte) (o []byte, err error)

UnmarshalMsg implements msgp.Unmarshaler

func (NullInt32) Value

func (n NullInt32) Value() (driver.Value, error)

Value implements the driver Valuer interface.

type NullInt64

type NullInt64 struct {
	Int64 int64
	Valid bool // Valid is true if Int64 is not NULL
}

NullInt64 - nullable int64

func Int64

func Int64(v int64) NullInt64

Int64 - converts int64 to NullInt64

func Int64Addr

func Int64Addr(v *int64) NullInt64

Int64Addr - converts int64 address to NullInt64

func Int64ToNullInt64 deprecated

func Int64ToNullInt64(v int64) NullInt64

Int64ToNullInt64 - converts int64 to NullInt64

Deprecated: use shorter variant

func (NullInt64) Addr

func (n NullInt64) Addr() *int64

func (*NullInt64) DecodeMsg added in v1.2.0

func (z *NullInt64) DecodeMsg(dc *msgp.Reader) (err error)

DecodeMsg implements msgp.Decodable

func (NullInt64) EncodeMsg added in v1.2.0

func (z NullInt64) EncodeMsg(en *msgp.Writer) (err error)

EncodeMsg implements msgp.Encodable

func (NullInt64) IsDefined

func (n NullInt64) IsDefined() bool

func (NullInt64) IsValid

func (n NullInt64) IsValid() bool

func (NullInt64) MarshalMsg added in v1.2.0

func (z NullInt64) MarshalMsg(b []byte) (o []byte, err error)

MarshalMsg implements msgp.Marshaler

func (NullInt64) Msgsize added in v1.2.0

func (z NullInt64) Msgsize() (s int)

Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message

func (*NullInt64) Scan

func (n *NullInt64) Scan(value interface{}) error

Scan - scan value from sql driver

func (*NullInt64) UnmarshalMsg added in v1.2.0

func (z *NullInt64) UnmarshalMsg(bts []byte) (o []byte, err error)

UnmarshalMsg implements msgp.Unmarshaler

func (NullInt64) Value

func (n NullInt64) Value() (driver.Value, error)

Value implements the driver Valuer interface.

type NullString

type NullString struct {
	String string
	Valid  bool // Valid is true if String is not NULL
}

NullString - nullable string

func String

func String(v string) NullString

String - converts string to NullString

func StringAddr

func StringAddr(v *string) NullString

StringAddr - converts string address to NullString

func StringToNullString deprecated

func StringToNullString(v string) NullString

StringToNullString - converts string to NullString

Deprecated: use shorter variant

func (NullString) Addr

func (n NullString) Addr() *string

func (*NullString) DecodeMsg added in v1.2.0

func (z *NullString) DecodeMsg(dc *msgp.Reader) (err error)

DecodeMsg implements msgp.Decodable

func (NullString) EncodeMsg added in v1.2.0

func (z NullString) EncodeMsg(en *msgp.Writer) (err error)

EncodeMsg implements msgp.Encodable

func (NullString) IsDefined

func (n NullString) IsDefined() bool

func (NullString) IsValid

func (n NullString) IsValid() bool

func (NullString) MarshalMsg added in v1.2.0

func (z NullString) MarshalMsg(b []byte) (o []byte, err error)

MarshalMsg implements msgp.Marshaler

func (NullString) Msgsize added in v1.2.0

func (z NullString) Msgsize() (s int)

Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message

func (*NullString) Scan

func (ns *NullString) Scan(value interface{}) error

Scan - scan value from sql driver

func (*NullString) UnmarshalMsg added in v1.2.0

func (z *NullString) UnmarshalMsg(bts []byte) (o []byte, err error)

UnmarshalMsg implements msgp.Unmarshaler

func (NullString) Value

func (ns NullString) Value() (driver.Value, error)

Value implements the driver Valuer interface.

type NullTime

type NullTime struct {
	Time  time.Time
	Valid bool // Valid is true if Time is not NULL
}

NullTime - nullable time.Time

func Time

func Time(v time.Time) NullTime

Time - converts time.Time to NullTime

func TimeAddr

func TimeAddr(v *time.Time) NullTime

TimeAddr - converts time.Time address to NullTime

func TimeToNullTime deprecated

func TimeToNullTime(v time.Time) NullTime

TimeToNullTime - converts time.Time to NullTime

Deprecated: use shorter variant

func (NullTime) Addr

func (n NullTime) Addr() *time.Time

func (*NullTime) DecodeMsg added in v1.2.0

func (z *NullTime) DecodeMsg(dc *msgp.Reader) (err error)

DecodeMsg implements msgp.Decodable

func (NullTime) EncodeMsg added in v1.2.0

func (z NullTime) EncodeMsg(en *msgp.Writer) (err error)

EncodeMsg implements msgp.Encodable

func (NullTime) IsDefined

func (n NullTime) IsDefined() bool

func (NullTime) IsValid

func (n NullTime) IsValid() bool

func (NullTime) MarshalMsg added in v1.2.0

func (z NullTime) MarshalMsg(b []byte) (o []byte, err error)

MarshalMsg implements msgp.Marshaler

func (NullTime) Msgsize added in v1.2.0

func (z NullTime) Msgsize() (s int)

Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message

func (NullTime) Proto added in v1.1.0

func (n NullTime) Proto() *timestamppb.Timestamp

func (*NullTime) Scan

func (n *NullTime) Scan(value interface{}) error

Scan - scan value from sql driver

func (*NullTime) UnmarshalMsg added in v1.2.0

func (z *NullTime) UnmarshalMsg(bts []byte) (o []byte, err error)

UnmarshalMsg implements msgp.Unmarshaler

func (NullTime) Value

func (n NullTime) Value() (driver.Value, error)

Value implements the driver Valuer interface.

type NullUint

type NullUint struct {
	Uint  uint
	Valid bool // Valid is true if Uint is not NULL
}

NullUint - nullable uint

func Uint

func Uint(v uint) NullUint

Uint - converts uint to NullUint

func UintAddr

func UintAddr(v *uint) NullUint

UintAddr - converts uint address to NullUint

func (NullUint) Addr

func (n NullUint) Addr() *uint

func (*NullUint) DecodeMsg added in v1.2.0

func (z *NullUint) DecodeMsg(dc *msgp.Reader) (err error)

DecodeMsg implements msgp.Decodable

func (NullUint) EncodeMsg added in v1.2.0

func (z NullUint) EncodeMsg(en *msgp.Writer) (err error)

EncodeMsg implements msgp.Encodable

func (NullUint) IsDefined

func (n NullUint) IsDefined() bool

func (NullUint) IsValid

func (n NullUint) IsValid() bool

func (NullUint) MarshalMsg added in v1.2.0

func (z NullUint) MarshalMsg(b []byte) (o []byte, err error)

MarshalMsg implements msgp.Marshaler

func (NullUint) Msgsize added in v1.2.0

func (z NullUint) Msgsize() (s int)

Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message

func (*NullUint) UnmarshalMsg added in v1.2.0

func (z *NullUint) UnmarshalMsg(bts []byte) (o []byte, err error)

UnmarshalMsg implements msgp.Unmarshaler

type NullUint8

type NullUint8 struct {
	Uint8 uint8
	Valid bool // Valid is true if Uint8 is not NULL
}

NullUint8 - nullable uint8

func Uint8

func Uint8(v uint8) NullUint8

Uint8 - converts uint8 to NullUint8

func Uint8Addr

func Uint8Addr(v *uint8) NullUint8

Uint8Addr - converts uint8 address to NullUint8

func (NullUint8) Addr

func (n NullUint8) Addr() *uint8

func (*NullUint8) DecodeMsg added in v1.2.0

func (z *NullUint8) DecodeMsg(dc *msgp.Reader) (err error)

DecodeMsg implements msgp.Decodable

func (NullUint8) EncodeMsg added in v1.2.0

func (z NullUint8) EncodeMsg(en *msgp.Writer) (err error)

EncodeMsg implements msgp.Encodable

func (NullUint8) IsDefined

func (n NullUint8) IsDefined() bool

func (NullUint8) IsValid

func (n NullUint8) IsValid() bool

func (NullUint8) MarshalMsg added in v1.2.0

func (z NullUint8) MarshalMsg(b []byte) (o []byte, err error)

MarshalMsg implements msgp.Marshaler

func (NullUint8) Msgsize added in v1.2.0

func (z NullUint8) Msgsize() (s int)

Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message

func (*NullUint8) UnmarshalMsg added in v1.2.0

func (z *NullUint8) UnmarshalMsg(bts []byte) (o []byte, err error)

UnmarshalMsg implements msgp.Unmarshaler

type NullUint16

type NullUint16 struct {
	Uint16 uint16
	Valid  bool // Valid is true if Uint16 is not NULL
}

NullUint16 - nullable uint16

func Uint16

func Uint16(v uint16) NullUint16

Uint16 - converts uint16 to NullUint16

func Uint16Addr

func Uint16Addr(v *uint16) NullUint16

Uint16Addr - converts uint16 address to NullUint16

func (NullUint16) Addr

func (n NullUint16) Addr() *uint16

func (*NullUint16) DecodeMsg added in v1.2.0

func (z *NullUint16) DecodeMsg(dc *msgp.Reader) (err error)

DecodeMsg implements msgp.Decodable

func (NullUint16) EncodeMsg added in v1.2.0

func (z NullUint16) EncodeMsg(en *msgp.Writer) (err error)

EncodeMsg implements msgp.Encodable

func (NullUint16) IsDefined

func (n NullUint16) IsDefined() bool

func (NullUint16) IsValid

func (n NullUint16) IsValid() bool

func (NullUint16) MarshalMsg added in v1.2.0

func (z NullUint16) MarshalMsg(b []byte) (o []byte, err error)

MarshalMsg implements msgp.Marshaler

func (NullUint16) Msgsize added in v1.2.0

func (z NullUint16) Msgsize() (s int)

Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message

func (*NullUint16) UnmarshalMsg added in v1.2.0

func (z *NullUint16) UnmarshalMsg(bts []byte) (o []byte, err error)

UnmarshalMsg implements msgp.Unmarshaler

type NullUint32

type NullUint32 struct {
	Uint32 uint32
	Valid  bool // Valid is true if Uint32 is not NULL
}

NullUint32 - nullable uint32

func Uint32

func Uint32(v uint32) NullUint32

Uint32 - converts uint32 to NullUint32

func Uint32Addr

func Uint32Addr(v *uint32) NullUint32

Uint32Addr - converts uint32 address to NullUint32

func (NullUint32) Addr

func (n NullUint32) Addr() *uint32

func (*NullUint32) DecodeMsg added in v1.2.0

func (z *NullUint32) DecodeMsg(dc *msgp.Reader) (err error)

DecodeMsg implements msgp.Decodable

func (NullUint32) EncodeMsg added in v1.2.0

func (z NullUint32) EncodeMsg(en *msgp.Writer) (err error)

EncodeMsg implements msgp.Encodable

func (NullUint32) IsDefined

func (n NullUint32) IsDefined() bool

func (NullUint32) IsValid

func (n NullUint32) IsValid() bool

func (NullUint32) MarshalMsg added in v1.2.0

func (z NullUint32) MarshalMsg(b []byte) (o []byte, err error)

MarshalMsg implements msgp.Marshaler

func (NullUint32) Msgsize added in v1.2.0

func (z NullUint32) Msgsize() (s int)

Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message

func (*NullUint32) UnmarshalMsg added in v1.2.0

func (z *NullUint32) UnmarshalMsg(bts []byte) (o []byte, err error)

UnmarshalMsg implements msgp.Unmarshaler

type NullUint64

type NullUint64 struct {
	Uint64 uint64
	Valid  bool // Valid is true if Uint64 is not NULL
}

NullUint64 - nullable uint64

func Uint64

func Uint64(v uint64) NullUint64

Uint64 - converts uint64 to NullUint64

func Uint64Addr

func Uint64Addr(v *uint64) NullUint64

Uint64Addr - converts uint64 address to NullUint64

func (NullUint64) Addr

func (n NullUint64) Addr() *uint64

func (*NullUint64) DecodeMsg added in v1.2.0

func (z *NullUint64) DecodeMsg(dc *msgp.Reader) (err error)

DecodeMsg implements msgp.Decodable

func (NullUint64) EncodeMsg added in v1.2.0

func (z NullUint64) EncodeMsg(en *msgp.Writer) (err error)

EncodeMsg implements msgp.Encodable

func (NullUint64) IsDefined

func (n NullUint64) IsDefined() bool

func (NullUint64) IsValid

func (n NullUint64) IsValid() bool

func (NullUint64) MarshalMsg added in v1.2.0

func (z NullUint64) MarshalMsg(b []byte) (o []byte, err error)

MarshalMsg implements msgp.Marshaler

func (NullUint64) Msgsize added in v1.2.0

func (z NullUint64) Msgsize() (s int)

Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message

func (*NullUint64) UnmarshalMsg added in v1.2.0

func (z *NullUint64) UnmarshalMsg(bts []byte) (o []byte, err error)

UnmarshalMsg implements msgp.Unmarshaler

type Validator

type Validator interface {
	IsValid() bool
}

Validator is implemented by all nan types and returns Valid field

Jump to