Documentation
¶
Index ¶
- type NullBool
- func (n NullBool) Addr() *bool
- func (z *NullBool) DecodeMsg(dc *msgp.Reader) (err error)
- func (z NullBool) EncodeMsg(en *msgp.Writer) (err error)
- func (n NullBool) IsDefined() bool
- func (n NullBool) IsValid() bool
- func (z NullBool) MarshalMsg(b []byte) (o []byte, err error)
- func (z NullBool) Msgsize() (s int)
- func (n *NullBool) Scan(value interface{}) error
- func (z *NullBool) UnmarshalMsg(bts []byte) (o []byte, err error)
- func (n NullBool) Value() (driver.Value, error)
- type NullFloat32
- func (n NullFloat32) Addr() *float32
- func (z *NullFloat32) DecodeMsg(dc *msgp.Reader) (err error)
- func (z NullFloat32) EncodeMsg(en *msgp.Writer) (err error)
- func (n NullFloat32) IsDefined() bool
- func (n NullFloat32) IsValid() bool
- func (z NullFloat32) MarshalMsg(b []byte) (o []byte, err error)
- func (z NullFloat32) Msgsize() (s int)
- func (n *NullFloat32) Scan(value interface{}) error
- func (z *NullFloat32) UnmarshalMsg(bts []byte) (o []byte, err error)
- func (n NullFloat32) Value() (driver.Value, error)
- type NullFloat64
- func (n NullFloat64) Addr() *float64
- func (z *NullFloat64) DecodeMsg(dc *msgp.Reader) (err error)
- func (z NullFloat64) EncodeMsg(en *msgp.Writer) (err error)
- func (n NullFloat64) IsDefined() bool
- func (n NullFloat64) IsValid() bool
- func (z NullFloat64) MarshalMsg(b []byte) (o []byte, err error)
- func (z NullFloat64) Msgsize() (s int)
- func (n *NullFloat64) Scan(value interface{}) error
- func (z *NullFloat64) UnmarshalMsg(bts []byte) (o []byte, err error)
- func (n NullFloat64) Value() (driver.Value, error)
- type NullInt
- func (n NullInt) Addr() *int
- func (z *NullInt) DecodeMsg(dc *msgp.Reader) (err error)
- func (z NullInt) EncodeMsg(en *msgp.Writer) (err error)
- func (n NullInt) IsDefined() bool
- func (n NullInt) IsValid() bool
- func (z NullInt) MarshalMsg(b []byte) (o []byte, err error)
- func (z NullInt) Msgsize() (s int)
- func (n *NullInt) Scan(value interface{}) error
- func (z *NullInt) UnmarshalMsg(bts []byte) (o []byte, err error)
- func (n NullInt) Value() (driver.Value, error)
- type NullInt8
- func (n NullInt8) Addr() *int8
- func (z *NullInt8) DecodeMsg(dc *msgp.Reader) (err error)
- func (z NullInt8) EncodeMsg(en *msgp.Writer) (err error)
- func (n NullInt8) IsDefined() bool
- func (n NullInt8) IsValid() bool
- func (z NullInt8) MarshalMsg(b []byte) (o []byte, err error)
- func (z NullInt8) Msgsize() (s int)
- func (n *NullInt8) Scan(value interface{}) error
- func (z *NullInt8) UnmarshalMsg(bts []byte) (o []byte, err error)
- func (n NullInt8) Value() (driver.Value, error)
- type NullInt16
- func (n NullInt16) Addr() *int16
- func (z *NullInt16) DecodeMsg(dc *msgp.Reader) (err error)
- func (z NullInt16) EncodeMsg(en *msgp.Writer) (err error)
- func (n NullInt16) IsDefined() bool
- func (n NullInt16) IsValid() bool
- func (z NullInt16) MarshalMsg(b []byte) (o []byte, err error)
- func (z NullInt16) Msgsize() (s int)
- func (n *NullInt16) Scan(value interface{}) error
- func (z *NullInt16) UnmarshalMsg(bts []byte) (o []byte, err error)
- func (n NullInt16) Value() (driver.Value, error)
- type NullInt32
- func (n NullInt32) Addr() *int32
- func (z *NullInt32) DecodeMsg(dc *msgp.Reader) (err error)
- func (z NullInt32) EncodeMsg(en *msgp.Writer) (err error)
- func (n NullInt32) IsDefined() bool
- func (n NullInt32) IsValid() bool
- func (z NullInt32) MarshalMsg(b []byte) (o []byte, err error)
- func (z NullInt32) Msgsize() (s int)
- func (n *NullInt32) Scan(value interface{}) error
- func (z *NullInt32) UnmarshalMsg(bts []byte) (o []byte, err error)
- func (n NullInt32) Value() (driver.Value, error)
- type NullInt64
- func (n NullInt64) Addr() *int64
- func (z *NullInt64) DecodeMsg(dc *msgp.Reader) (err error)
- func (z NullInt64) EncodeMsg(en *msgp.Writer) (err error)
- func (n NullInt64) IsDefined() bool
- func (n NullInt64) IsValid() bool
- func (z NullInt64) MarshalMsg(b []byte) (o []byte, err error)
- func (z NullInt64) Msgsize() (s int)
- func (n *NullInt64) Scan(value interface{}) error
- func (z *NullInt64) UnmarshalMsg(bts []byte) (o []byte, err error)
- func (n NullInt64) Value() (driver.Value, error)
- type NullString
- func (n NullString) Addr() *string
- func (z *NullString) DecodeMsg(dc *msgp.Reader) (err error)
- func (z NullString) EncodeMsg(en *msgp.Writer) (err error)
- func (n NullString) IsDefined() bool
- func (n NullString) IsValid() bool
- func (z NullString) MarshalMsg(b []byte) (o []byte, err error)
- func (z NullString) Msgsize() (s int)
- func (ns *NullString) Scan(value interface{}) error
- func (z *NullString) UnmarshalMsg(bts []byte) (o []byte, err error)
- func (ns NullString) Value() (driver.Value, error)
- type NullTime
- func (n NullTime) Addr() *time.Time
- func (z *NullTime) DecodeMsg(dc *msgp.Reader) (err error)
- func (z NullTime) EncodeMsg(en *msgp.Writer) (err error)
- func (n NullTime) IsDefined() bool
- func (n NullTime) IsValid() bool
- func (z NullTime) MarshalMsg(b []byte) (o []byte, err error)
- func (z NullTime) Msgsize() (s int)
- func (n NullTime) Proto() *timestamppb.Timestamp
- func (n *NullTime) Scan(value interface{}) error
- func (z *NullTime) UnmarshalMsg(bts []byte) (o []byte, err error)
- func (n NullTime) Value() (driver.Value, error)
- type NullUint
- func (n NullUint) Addr() *uint
- func (z *NullUint) DecodeMsg(dc *msgp.Reader) (err error)
- func (z NullUint) EncodeMsg(en *msgp.Writer) (err error)
- func (n NullUint) IsDefined() bool
- func (n NullUint) IsValid() bool
- func (z NullUint) MarshalMsg(b []byte) (o []byte, err error)
- func (z NullUint) Msgsize() (s int)
- func (z *NullUint) UnmarshalMsg(bts []byte) (o []byte, err error)
- type NullUint8
- func (n NullUint8) Addr() *uint8
- func (z *NullUint8) DecodeMsg(dc *msgp.Reader) (err error)
- func (z NullUint8) EncodeMsg(en *msgp.Writer) (err error)
- func (n NullUint8) IsDefined() bool
- func (n NullUint8) IsValid() bool
- func (z NullUint8) MarshalMsg(b []byte) (o []byte, err error)
- func (z NullUint8) Msgsize() (s int)
- func (z *NullUint8) UnmarshalMsg(bts []byte) (o []byte, err error)
- type NullUint16
- func (n NullUint16) Addr() *uint16
- func (z *NullUint16) DecodeMsg(dc *msgp.Reader) (err error)
- func (z NullUint16) EncodeMsg(en *msgp.Writer) (err error)
- func (n NullUint16) IsDefined() bool
- func (n NullUint16) IsValid() bool
- func (z NullUint16) MarshalMsg(b []byte) (o []byte, err error)
- func (z NullUint16) Msgsize() (s int)
- func (z *NullUint16) UnmarshalMsg(bts []byte) (o []byte, err error)
- type NullUint32
- func (n NullUint32) Addr() *uint32
- func (z *NullUint32) DecodeMsg(dc *msgp.Reader) (err error)
- func (z NullUint32) EncodeMsg(en *msgp.Writer) (err error)
- func (n NullUint32) IsDefined() bool
- func (n NullUint32) IsValid() bool
- func (z NullUint32) MarshalMsg(b []byte) (o []byte, err error)
- func (z NullUint32) Msgsize() (s int)
- func (z *NullUint32) UnmarshalMsg(bts []byte) (o []byte, err error)
- type NullUint64
- func (n NullUint64) Addr() *uint64
- func (z *NullUint64) DecodeMsg(dc *msgp.Reader) (err error)
- func (z NullUint64) EncodeMsg(en *msgp.Writer) (err error)
- func (n NullUint64) IsDefined() bool
- func (n NullUint64) IsValid() bool
- func (z NullUint64) MarshalMsg(b []byte) (o []byte, err error)
- func (z NullUint64) Msgsize() (s int)
- func (z *NullUint64) UnmarshalMsg(bts []byte) (o []byte, err error)
- type Validator
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type NullBool ¶
NullBool - nullable bool
func BoolToNullBool
deprecated
func (NullBool) MarshalMsg ¶ added in v1.2.0
MarshalMsg implements msgp.Marshaler
func (NullBool) Msgsize ¶ added in v1.2.0
Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message
func (*NullBool) UnmarshalMsg ¶ added in v1.2.0
UnmarshalMsg implements msgp.Unmarshaler
type NullFloat32 ¶
NullFloat32 - nullable float32
func Float32Addr ¶
func Float32Addr(v *float32) NullFloat32
Float32Addr - converts float32 address to NullFloat32
func Float32ToNullFloat32
deprecated
func Float32ToNullFloat32(v float32) NullFloat32
Float32ToNullFloat32 - converts float32 to NullFloat32
Deprecated: use shorter variant
func (NullFloat32) Addr ¶
func (n NullFloat32) Addr() *float32
func (*NullFloat32) DecodeMsg ¶ added in v1.2.0
func (z *NullFloat32) DecodeMsg(dc *msgp.Reader) (err error)
DecodeMsg implements msgp.Decodable
func (NullFloat32) EncodeMsg ¶ added in v1.2.0
func (z NullFloat32) EncodeMsg(en *msgp.Writer) (err error)
EncodeMsg implements msgp.Encodable
func (NullFloat32) IsDefined ¶
func (n NullFloat32) IsDefined() bool
func (NullFloat32) IsValid ¶
func (n NullFloat32) IsValid() bool
func (NullFloat32) MarshalMsg ¶ added in v1.2.0
func (z NullFloat32) MarshalMsg(b []byte) (o []byte, err error)
MarshalMsg implements msgp.Marshaler
func (NullFloat32) Msgsize ¶ added in v1.2.0
func (z NullFloat32) Msgsize() (s int)
Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message
func (*NullFloat32) Scan ¶
func (n *NullFloat32) Scan(value interface{}) error
Scan - scan value from sql driver
func (*NullFloat32) UnmarshalMsg ¶ added in v1.2.0
func (z *NullFloat32) UnmarshalMsg(bts []byte) (o []byte, err error)
UnmarshalMsg implements msgp.Unmarshaler
type NullFloat64 ¶
NullFloat64 - nullable float64
func Float64Addr ¶
func Float64Addr(v *float64) NullFloat64
Float64Addr - converts float64 address to NullFloat64
func Float64ToNullFloat64
deprecated
func Float64ToNullFloat64(v float64) NullFloat64
Float64ToNullFloat64 - converts float64 to NullFloat64
Deprecated: use shorter variant
func (NullFloat64) Addr ¶
func (n NullFloat64) Addr() *float64
func (*NullFloat64) DecodeMsg ¶ added in v1.2.0
func (z *NullFloat64) DecodeMsg(dc *msgp.Reader) (err error)
DecodeMsg implements msgp.Decodable
func (NullFloat64) EncodeMsg ¶ added in v1.2.0
func (z NullFloat64) EncodeMsg(en *msgp.Writer) (err error)
EncodeMsg implements msgp.Encodable
func (NullFloat64) IsDefined ¶
func (n NullFloat64) IsDefined() bool
func (NullFloat64) IsValid ¶
func (n NullFloat64) IsValid() bool
func (NullFloat64) MarshalMsg ¶ added in v1.2.0
func (z NullFloat64) MarshalMsg(b []byte) (o []byte, err error)
MarshalMsg implements msgp.Marshaler
func (NullFloat64) Msgsize ¶ added in v1.2.0
func (z NullFloat64) Msgsize() (s int)
Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message
func (*NullFloat64) Scan ¶
func (n *NullFloat64) Scan(value interface{}) error
Scan - scan value from sql driver
func (*NullFloat64) UnmarshalMsg ¶ added in v1.2.0
func (z *NullFloat64) UnmarshalMsg(bts []byte) (o []byte, err error)
UnmarshalMsg implements msgp.Unmarshaler
type NullInt ¶
NullInt - nullable int
func IntToNullInt
deprecated
func (NullInt) MarshalMsg ¶ added in v1.2.0
MarshalMsg implements msgp.Marshaler
func (NullInt) Msgsize ¶ added in v1.2.0
Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message
func (*NullInt) UnmarshalMsg ¶ added in v1.2.0
UnmarshalMsg implements msgp.Unmarshaler
type NullInt8 ¶
NullInt8 - nullable int8
func Int8ToNullInt8
deprecated
func (NullInt8) MarshalMsg ¶ added in v1.2.0
MarshalMsg implements msgp.Marshaler
func (NullInt8) Msgsize ¶ added in v1.2.0
Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message
func (*NullInt8) UnmarshalMsg ¶ added in v1.2.0
UnmarshalMsg implements msgp.Unmarshaler
type NullInt16 ¶
NullInt16 - nullable int16
func Int16ToNullInt16
deprecated
func (NullInt16) MarshalMsg ¶ added in v1.2.0
MarshalMsg implements msgp.Marshaler
func (NullInt16) Msgsize ¶ added in v1.2.0
Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message
func (*NullInt16) UnmarshalMsg ¶ added in v1.2.0
UnmarshalMsg implements msgp.Unmarshaler
type NullInt32 ¶
NullInt32 - nullable int32
func Int32ToNullInt32
deprecated
func (NullInt32) MarshalMsg ¶ added in v1.2.0
MarshalMsg implements msgp.Marshaler
func (NullInt32) Msgsize ¶ added in v1.2.0
Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message
func (*NullInt32) UnmarshalMsg ¶ added in v1.2.0
UnmarshalMsg implements msgp.Unmarshaler
type NullInt64 ¶
NullInt64 - nullable int64
func Int64ToNullInt64
deprecated
func (NullInt64) MarshalMsg ¶ added in v1.2.0
MarshalMsg implements msgp.Marshaler
func (NullInt64) Msgsize ¶ added in v1.2.0
Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message
func (*NullInt64) UnmarshalMsg ¶ added in v1.2.0
UnmarshalMsg implements msgp.Unmarshaler
type NullString ¶
NullString - nullable string
func StringAddr ¶
func StringAddr(v *string) NullString
StringAddr - converts string address to NullString
func StringToNullString
deprecated
func StringToNullString(v string) NullString
StringToNullString - converts string to NullString
Deprecated: use shorter variant
func (NullString) Addr ¶
func (n NullString) Addr() *string
func (*NullString) DecodeMsg ¶ added in v1.2.0
func (z *NullString) DecodeMsg(dc *msgp.Reader) (err error)
DecodeMsg implements msgp.Decodable
func (NullString) EncodeMsg ¶ added in v1.2.0
func (z NullString) EncodeMsg(en *msgp.Writer) (err error)
EncodeMsg implements msgp.Encodable
func (NullString) IsDefined ¶
func (n NullString) IsDefined() bool
func (NullString) IsValid ¶
func (n NullString) IsValid() bool
func (NullString) MarshalMsg ¶ added in v1.2.0
func (z NullString) MarshalMsg(b []byte) (o []byte, err error)
MarshalMsg implements msgp.Marshaler
func (NullString) Msgsize ¶ added in v1.2.0
func (z NullString) Msgsize() (s int)
Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message
func (*NullString) Scan ¶
func (ns *NullString) Scan(value interface{}) error
Scan - scan value from sql driver
func (*NullString) UnmarshalMsg ¶ added in v1.2.0
func (z *NullString) UnmarshalMsg(bts []byte) (o []byte, err error)
UnmarshalMsg implements msgp.Unmarshaler
type NullTime ¶
NullTime - nullable time.Time
func TimeToNullTime
deprecated
func (NullTime) MarshalMsg ¶ added in v1.2.0
MarshalMsg implements msgp.Marshaler
func (NullTime) Msgsize ¶ added in v1.2.0
Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message
func (NullTime) Proto ¶ added in v1.1.0
func (n NullTime) Proto() *timestamppb.Timestamp
func (*NullTime) UnmarshalMsg ¶ added in v1.2.0
UnmarshalMsg implements msgp.Unmarshaler
type NullUint ¶
NullUint - nullable uint
func (NullUint) MarshalMsg ¶ added in v1.2.0
MarshalMsg implements msgp.Marshaler
type NullUint8 ¶
NullUint8 - nullable uint8
func (NullUint8) MarshalMsg ¶ added in v1.2.0
MarshalMsg implements msgp.Marshaler
type NullUint16 ¶
NullUint16 - nullable uint16
func Uint16Addr ¶
func Uint16Addr(v *uint16) NullUint16
Uint16Addr - converts uint16 address to NullUint16
func (NullUint16) Addr ¶
func (n NullUint16) Addr() *uint16
func (*NullUint16) DecodeMsg ¶ added in v1.2.0
func (z *NullUint16) DecodeMsg(dc *msgp.Reader) (err error)
DecodeMsg implements msgp.Decodable
func (NullUint16) EncodeMsg ¶ added in v1.2.0
func (z NullUint16) EncodeMsg(en *msgp.Writer) (err error)
EncodeMsg implements msgp.Encodable
func (NullUint16) IsDefined ¶
func (n NullUint16) IsDefined() bool
func (NullUint16) IsValid ¶
func (n NullUint16) IsValid() bool
func (NullUint16) MarshalMsg ¶ added in v1.2.0
func (z NullUint16) MarshalMsg(b []byte) (o []byte, err error)
MarshalMsg implements msgp.Marshaler
func (NullUint16) Msgsize ¶ added in v1.2.0
func (z NullUint16) Msgsize() (s int)
Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message
func (*NullUint16) UnmarshalMsg ¶ added in v1.2.0
func (z *NullUint16) UnmarshalMsg(bts []byte) (o []byte, err error)
UnmarshalMsg implements msgp.Unmarshaler
type NullUint32 ¶
NullUint32 - nullable uint32
func Uint32Addr ¶
func Uint32Addr(v *uint32) NullUint32
Uint32Addr - converts uint32 address to NullUint32
func (NullUint32) Addr ¶
func (n NullUint32) Addr() *uint32
func (*NullUint32) DecodeMsg ¶ added in v1.2.0
func (z *NullUint32) DecodeMsg(dc *msgp.Reader) (err error)
DecodeMsg implements msgp.Decodable
func (NullUint32) EncodeMsg ¶ added in v1.2.0
func (z NullUint32) EncodeMsg(en *msgp.Writer) (err error)
EncodeMsg implements msgp.Encodable
func (NullUint32) IsDefined ¶
func (n NullUint32) IsDefined() bool
func (NullUint32) IsValid ¶
func (n NullUint32) IsValid() bool
func (NullUint32) MarshalMsg ¶ added in v1.2.0
func (z NullUint32) MarshalMsg(b []byte) (o []byte, err error)
MarshalMsg implements msgp.Marshaler
func (NullUint32) Msgsize ¶ added in v1.2.0
func (z NullUint32) Msgsize() (s int)
Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message
func (*NullUint32) UnmarshalMsg ¶ added in v1.2.0
func (z *NullUint32) UnmarshalMsg(bts []byte) (o []byte, err error)
UnmarshalMsg implements msgp.Unmarshaler
type NullUint64 ¶
NullUint64 - nullable uint64
func Uint64Addr ¶
func Uint64Addr(v *uint64) NullUint64
Uint64Addr - converts uint64 address to NullUint64
func (NullUint64) Addr ¶
func (n NullUint64) Addr() *uint64
func (*NullUint64) DecodeMsg ¶ added in v1.2.0
func (z *NullUint64) DecodeMsg(dc *msgp.Reader) (err error)
DecodeMsg implements msgp.Decodable
func (NullUint64) EncodeMsg ¶ added in v1.2.0
func (z NullUint64) EncodeMsg(en *msgp.Writer) (err error)
EncodeMsg implements msgp.Encodable
func (NullUint64) IsDefined ¶
func (n NullUint64) IsDefined() bool
func (NullUint64) IsValid ¶
func (n NullUint64) IsValid() bool
func (NullUint64) MarshalMsg ¶ added in v1.2.0
func (z NullUint64) MarshalMsg(b []byte) (o []byte, err error)
MarshalMsg implements msgp.Marshaler
func (NullUint64) Msgsize ¶ added in v1.2.0
func (z NullUint64) Msgsize() (s int)
Msgsize returns an upper bound estimate of the number of bytes occupied by the serialized message
func (*NullUint64) UnmarshalMsg ¶ added in v1.2.0
func (z *NullUint64) UnmarshalMsg(bts []byte) (o []byte, err error)
UnmarshalMsg implements msgp.Unmarshaler